/****************************************************************************/
/*	Copyright (c) 2009, Bendor Research Pty. Ltd. All rights reserved.		*/
/*	This software is released under the GNU General Public License, version	*/
/*	3, with the exemptions that 1) the header files installed by this 	 	*/
/*	package can be included in closed-source code and 2) the libraries		*/
/*	built by this package can be statically linked into a closed-source 	*/
/*	binary. See the file LICENSE for the details.							*/
/*	This software is provided "AS IS", without any warranty or guarantee.	*/
/*	By using this software you acknowledge that neither Bendor Research nor	*/
/*	any of its personnel or affiliates can be held liable for any damages,	*/
/*	including, but not limited to, loss of business, loss of money, loss of */
/*	life, loss of reputation, arising out of this software being faulty or	*/
/*	not performing as advertised, even if Bendor Research was aware of such	*/
/*	faults in the software. You use this software at your own risk, any and */
/*	all liabilities that arise out of your using this software are strictly	*/
/*	yours.																	*/
/****************************************************************************/

#include <string.h>

/** @addtogroup string */
/** @{ */

/**
*	Compare two memory regions.
*
*	The function compares the two memory areas byte after byte, treating the
*	bytes as unsigned chars.
*	The comparison stops at the first byte that is different or when \p n
*	bytes have been compared.
*
*	@param	p1		Pointer to the first memory aread
*	@param	p2		Pointer to the second memory area
*	@param	n		Length of the comparison.
*
*	@return			An integer value that is 0 if p1 and p2 are identical
*					in their first n bytes, a negative number if s1 is
*					smaller that s2 and a positive number if s1 is greater
*					than s2. The actual numeric value of the return value is
*					undeterminate, only its signum is significant.
*/

int		memcmp( const void *p1, const void *p2, size_t n )
{
unsigned char	a, *ap;
unsigned char	b, *bp;

	ap = (unsigned char *) p1;
	bp = (unsigned char *) p2;

	while ( n-- ) {

		a = *ap++;
		b = *bp++;
		if ( a != b ) return( a - b );
	}

	return( 0 );
}

/** @} */

